==> cms-db_v0.7.9.tar.gz: admin/renameinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('includes');
include('locale.inc.php');
$locale = new LocalizingClass('includes');
?>
<?php
if (isset($_POST['button'])) {
	$inc = $_POST['inc'];
	$name = $_POST['new'];
	$name = str_replace(" " ,"_", $name);
	$name = str_replace("&" ,"AND", $name);
	if (!preg_match('/[^a-z0-9_-]/i', $name)) {
		if (!file_exists('../data/includes/'.$name)) {
			if (!rename('../data/includes/'.$inc, '../data/includes/'.$name)) {
				include('error.inc.php');
				throw_error(locale('desc_rename-error',true), 'renameinc.php?inc='.$inc.'&'.SID);
			}
			header('Location: includes.php?'.SID);
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-name',true), 'renameinc.php?inc='.$inc.'&'.SID);
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-specialchars',true), 'renameinc.php?inc='.$inc.'&'.SID);
	}
} else {
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_rename') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_rename') ?></h1>
<p>
	<form action="renameinc.php?<?php echo SID ?>" method="POST">
		<input type="hidden" name="inc" value="<?php echo $_GET['inc'] ?>" />
		<?php printf(locale('desc_rename',true), $_GET['inc']) ?>
		<input type="text" name="new" value="" /><br />
		<input type="submit" name="button" value="<?php locale('button_ok') ?>">
		<a href="includes.php?<?php echo SID ?>"><?php locale('button_cancel') ?></a>
	</form>
</p>

</body>
</html>

<?php
}
?>

==> cms-db_v0.8.1.tar.gz: admin/renameinc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('includes');
include('locale.inc.php');
$locale = new LocalizingClass('includes');
?>
<?php
if (isset($_POST['button'])) {
	$inc = $_POST['inc'];
	$name = $_POST['new'];
	$name = str_replace(" " ,"_", $name);
	$name = str_replace("&" ,"AND", $name);
	if (!preg_match('/[^a-z0-9_-]/i', $name)) {
		if (!file_exists('../data/includes/'.$name)) {
			if (!rename('../data/includes/'.$inc, '../data/includes/'.$name)) {
				include('error.inc.php');
				throw_error(locale('desc_rename-error',true), 'renameinc.php?inc='.$inc.'&'.SID.csrf_protection_get());
			}
			header('Location: includes.php?'.SID.csrf_protection_get());
		} else {
			include('error.inc.php');
			throw_error(locale('desc_error-name',true), 'renameinc.php?inc='.$inc.'&'.SID.csrf_protection_get());
		}
	} else {
		include('error.inc.php');
		throw_error(locale('desc_error-specialchars',true), 'renameinc.php?inc='.$inc.'&'.SID.csrf_protection_get());
	}
} else {
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_rename') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_rename') ?></h1>
<p>
	<form action="renameinc.php?<?php echo SID; csrf_protection_get_html() ?>" method="POST">
		<input type="hidden" name="inc" value="<?php echo $_GET['inc'] ?>" />
		<?php printf(locale('desc_rename',true), $_GET['inc']) ?>
		<input type="text" name="new" value="" /><br />
		<input type="submit" name="button" value="<?php locale('button_ok') ?>">
		<a href="includes.php?<?php echo SID; csrf_protection_get_html() ?>" class="nonewtab"><?php locale('button_cancel') ?></a>
	</form>
</p>

</body>
</html>

<?php
}
?>
